#
# spec file for package rt-tests
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rt-tests
Version:        1.3
Release:        lp151.1.2
Summary:        Realtime Kernel Testsuite
License:        GPL-2.0-only
Group:          System/Benchmark
URL:            https://git.kernel.org/pub/scm/utils/rt-tests/rt-tests.git
Source0:        https://git.kernel.org/pub/scm/utils/rt-tests/rt-tests.git/snapshot/rt-tests-%{version}.tar.gz
BuildRequires:  libnuma-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python2-base
Conflicts:      hackbench
# Only supported on intel architectures
ExclusiveArch:  %{ix86} x86_64

%description
The Realtime Kernel Testsuite measures real-time attributes of the kernel,
specifically timer and signal latency and the functionality of Priority
Inheritance Mutexes.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
make %{?_smp_mflags}

%install
%make_install prefix=%{_prefix}
rm -rf %{buildroot}%{_prefix}/src/backfire

%files
%license COPYING
%doc MAINTAINERS README.markdown
%{_bindir}/cyclicdeadline
%{_bindir}/cyclictest
%{_bindir}/deadline_test
%{_bindir}/hackbench
%{_bindir}/hwlatdetect
%{_bindir}/pi_stress
%{_bindir}/pip_stress
%{_bindir}/pmqtest
%{_bindir}/ptsematest
%{_bindir}/queuelat
%{_bindir}/rt-migrate-test
%{_bindir}/sendme
%{_bindir}/signaltest
%{_bindir}/sigwaittest
%{_bindir}/svsematest
%{python2_sitelib}/hwlatdetect.py
%{_mandir}/man4/backfire.4%{?ext_man}
%{_mandir}/man8/cyclictest.8%{?ext_man}
%{_mandir}/man8/hackbench.8%{?ext_man}
%{_mandir}/man8/hwlatdetect.8%{?ext_man}
%{_mandir}/man8/pi_stress.8%{?ext_man}
%{_mandir}/man8/pmqtest.8%{?ext_man}
%{_mandir}/man8/ptsematest.8%{?ext_man}
%{_mandir}/man8/rt-migrate-test.8%{?ext_man}
%{_mandir}/man8/sendme.8%{?ext_man}
%{_mandir}/man8/signaltest.8%{?ext_man}
%{_mandir}/man8/sigwaittest.8%{?ext_man}
%{_mandir}/man8/svsematest.8%{?ext_man}

%changelog
* Thu Sep 13 2018 Jan Engelhardt <jengelh@inai.de>
- Fix grammar in description.
- Have some more %%make_install.
* Thu Sep 13 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.3
- Cleanup spec file
* Thu Sep 13 2018 Jeffrey Cheung <jcheung@suse.com>
- This is initial to SLERT15 SP1 [fate#326547]
* Mon Jul 30 2018 jcheung@suse.com
- Update to 1.0
  Fate#323312 - Upgrade rt-tests to v1.0
  cyclictest: stop any tracing after hitting a breaktrace threshold
  rt-tests: Makefile: Assume numa_parse_cpustring_all available
  rt-tests: Add man page for rt-migrate-test
  rt-tests: Update the cyclictest man page
  rt-tests: Add missing option to hwlatdetect man page
  rt-tests: Housekeeping fix some spelling errors.
  rt-tests: hwlat.txt: smidetect renamed to hwlatdetect
  rt-tests: Remove doc/release-checklist.txt
  rt-tests: Makefile - bump version to 1.0
* Fri Jul 27 2018 jcheung@suse.com
- Submit to SLERT12 SP4
* Tue Apr 25 2017 jcheung@suse.com
- Submit to SLERT12-SP3
* Thu Dec  8 2016 jcheung@suse.com
- Apply this version to SLE-12-SP2
* Thu Jan 14 2016 jcheung@suse.com
- Apply this version to SLE-12-SP1
* Fri Jul 10 2015 jcheung@suse.com
-
- Add the "COPYING" file in the %%doc section
-
* Thu Jul  9 2015 jcheung@suse.com
-
- license update: GPL-2.0
- We now use SPDX license sytnax.
-
* Wed Jul  8 2015 cdenicolo@suse.com
-
- license update: GPL-2.0
- please use SPDX  license sytnax.
* Tue Jun 30 2015 Mike Galbraith <mgalbraith@suse.de>
- Update to 0.89
  This is the last release suitable for SLE11
- Drop legacy/unbuildable backfire/sendme
- Drop legacy SLERT10 scripts
- We now ship virgin source with only hwlatency detect and broken
  legacy code removed.
* Thu Nov 24 2011 Mike Galbraith <mgalbraith@suse.de>
- Fix up spec file BuildRequires/Requires for libnuma
* Thu Nov 24 2011 Mike Galbraith <mgalbraith@suse.de>
- Update to 0.83
* Fri Aug  6 2010 Mike Galbraith <mgalbraith@suse.de>
- Update to 0.72
- Update signaltest display and trace capability to match cyclictest,
  and provide a man page for same.
* Fri Feb 26 2010 jblunck@suse.de
- Update to 0.64.
* Mon Oct 12 2009 sdietrich@suse.de
- Update to 0.53.
* Tue Jul  7 2009 sdietrich@suse.de
- Update to 0.47.
* Mon Jul  6 2009 sdietrich@suse.de
- Update to 0.46. Drop: histogram_exceed_limit.patch
* Thu Jul  2 2009 sdietrich@suse.de
- Update to 0.45. Drop:
  change-output-format-to-allow-6-digits.patch
  clock_nanosleep_interrupt.patch
* Thu Jul  2 2009 sdietrich@suse.de
- Rework Suse-added patches after sending upstream.
  - Fold re-introduce-HIST_MAX-and-silently-cap-the-histogram.patch
  into histogram_exceed_limit.patch.
  - Add proper explanation to change-output-format-to-allow-6-digits.patch
* Mon Jun 29 2009 sdietrich@suse.de
- Update to 0.43
* Thu Jun 25 2009 sdietrich@suse.de
- Update to 0.42
* Tue Apr  7 2009 sdietrich@suse.de
- Update to v. 0.34.
* Thu Aug 21 2008 dgollub@suse.de
- cyclictest_make_all_thread_intervals_equal_for_histogram.patch:
  Change thread interal for histogram mode
* Thu Aug 21 2008 dgollub@suse.de
- updated histogram_exceed_limit.patch:
  Sample doomsday spikes which exceed histogram limit in last bucket
* Tue Aug 19 2008 dgollub@suse.de
- histogram_exceed_limit.patch: handled histogram limit exceed
* Wed Jul 16 2008 dgollub@suse.de
- updated to rt-tests 0.24
  * mlockall option got added (removed mlockall patches)
- cyclictest: fixed staggering of priorities for multiple threads
  bnc#408421
* Tue Jul  8 2008 dgollub@suse.de
- updated to rt-tests 0.23
  * fixed processing of cyclictest command line arguments
  * fixed oscilloscope mode which didn't work correctly with more
    then one thread
* Wed May 14 2008 dgollub@suse.de
- updated to rt-tests 0.21
  * support for CPU affinity
- dropped memlock patch in favor of memlock patch by Clark Williams
- updated command arguments for cyclictest_run.sh for CPU affinity
* Thu May  8 2008 dgollub@suse.de
- added memlock option to lock the memory to avoid major pagefaults
* Tue Apr 22 2008 dgollub@suse.de
- removed ctcs2 glue subpackage
* Tue Apr 22 2008 dgollub@suse.de
- decreased the number of histogram samples from 20000 to 10000
  in cyclictest_run.sh
- fixed wrong escaping from in gnuplot script for ploting graph
  title in cyclictest_plot.sh
* Tue Apr 22 2008 dgollub@suse.de
- Avoid segfault of cyclictest if it gets immediately interrupted
  clock_nanosleep_interrupt.patch
* Fri Feb 29 2008 dgollub@suse.de
- Added ctcs glue subpackages
* Wed Feb 27 2008 dgollub@suse.de
- Added test helper scripts:
  * cyclictest_run.sh:
  calls cyclictests with adjusted number of CPUs and enables
  output of histogram
  * cyclictest_plot.sh
  generate a latency graph with the histogram output of cyclictests
- Fixed shebang of helper script and require for both script the first argument
  Otherwise print usage.
* Wed Feb 27 2008 dgollub@suse.de
- Added histogramm patch for cyclictest
* Tue Feb 26 2008 dgollub@suse.de
- disabled ia64, s390 and s390x for now to avoid build issues
  with struct sigevent and unionen member  _sigev_un._tid
* Thu Feb 21 2008 dgollub@suse.de
- initial checkin of rt-tests (Version 0.19)
